@@ -10,6 +10,9 @@ __PACKAGE__->config
       create_requires => ['cd', 'title' ],
       create_allows => ['cd', 'title', 'position' ],
       update_allows => ['title', 'position', { cd => ['*'] }],
+      page => 1,
+      count => 10,
+      use_json_boolean => 1,
       );
 
 1;
