@@ -1,5 +1,4 @@
 package RestTest::Model::RestTestDB;
-our $VERSION = '2.001003';
 
 use strict;
 use warnings;
@@ -10,11 +9,11 @@ use Catalyst::Utils;
 __PACKAGE__->config(
 					schema_class => 'RestTest::Schema',
 					connect_info => [
-                        "DBI:SQLite:t/var/DBIxClass.db",
+                        "dbi:SQLite:t/var/DBIxClass.db",
                         "",
                         "",
 					   {AutoCommit => 1}
-                      ]					  
+                      ]
 );
 
 1;
